function [I,J,emid] = findTEACanditates(str,dt,s)
% findTEACanditates: find tip-edge anastomosis canditates
%
% str             l-system string
% dt              time step, not used
% s               random seed  
%
% [I,J]           I    hyphae tip indices,   J edge ... indices
%
%
% Copyright 2012-2014 Daniel Leitner & Andrea Schnepf. See license.txt for details.
%

I=[];
J=[];

HI = find(str(:,1)==400); % tip indices
X = str(HI+1,1:3);

[x1,x2,~,~,~,~,ind]=getSegments(str);
emid = (x1+x2)/2;
eind = ind;
emid(str(ind,5)<100,:) = []; % edge mid points
eind(str(ind,5)<100) = []; % hyphal edge indices

% partition edge indices
N=100;
if length(eind)>N
    for k = 1 : ceil(length(eind)/N)        
        edgeIND{k} = 1+(k-1)*N : min(k*N,length(eind));        
        offset(k) = 0 + (k-1)*N;
    end    
else
    edgeIND{1} = 1:length(eind);  
    offset = 0;
end


for k = 1 : length(edgeIND) % for each partition
    
    idd1 = str(HI,6); % clever trick to avoid anastomosis within same branch
    idd2 = str(eind(edgeIND{k}),6);
    %fprintf('pdist2 = %g * %g \n',length(idd1),length(idd2));
    dist = pdist2(idd1,idd2);
    PM = 1e-16./dist; % very small or inf
    
    thresh = 0.01; % TODO! put into mycParameters
    
    %fprintf('pdist2 = %g * %g \n',size(X,1),size(emid(edgeIND{k},:),1));
    dist  = pdist2(X,emid(edgeIND{k},:)); % entry i,j is the distance between points i and j in vector x
    dist  = (dist+PM)<thresh;
    [i,j] = find(dist);
    
    P = 1; % (unused) TODO  put inot mycParameters
    iP = rand(s,size(i)) < P; % how do we want to model it? conceptual model? % dt should be in there
    i=i(iP);
    j=j(iP);
    
    j = j + offset(k); % TODO !!!!!!!!!!
    
    I = [I;HI(i)];
    J = [J;j];
    
end
