%========================================================================
% Automatically generated by Dicot.m: 
% Modify this file to describe root-soil interactions
%========================================================================

p = cell(4,1);

%-----------------------------------------
% Tap root
%-----------------------------------------

% Parameters editable by the GUI [mean, sd]
p{1}.r = [2.04, 0]; % Initial elongation rate (cm/day)
p{1}.a = [0.029, 0]; % Root radius (cm)  
p{1}.lb = [2.59, 2.63]; % Length of basal zone (cm)        
p{1}.la = [4.33, 4.6]; % Length of apical zone (cm)                    
p{1}.ln = [0.26, 0.24]; % Length between laterals (cm)
p{1}.nob = [103, 0]; % Maximal number of laterals (1)

% Additional parameters (predefined values, not altered by GUI)
p{1}.name = 'Tap root'; % Name of the root type
p{1}.color = [0.5, 0, 0]; % Color of the root (rgb)
type = 1; % Type of tropism (1: 2:)
N = 1.5; % Strength of tropism
sigma = 0.2; % Expected change of root tip heading (rad/cm)
p{1}.tropism = [type, N, sigma]; % Root tropism
p{1}.dx = 0.25; % Spatial resolution along root axis (cm)
p{1}.rlt = [Inf, 0]; % Maximal root life time [mean, std] (days)
p{1}.gf = 1; % Type of growth function (1: negative exponential, 2: linear)

% Preset by GUI 
p{1}.theta = [0, 0]; % Insertion angle (rad)
p{1}.successor = [2, 1]; % Laterals [type,probability;type,probability;...]
p{1}.ief = @(x) 1; % impede elongation function: scales root elongation
p{1}.ibf = @(x) 1; % impede branching function: scales branching probability 
p{1}.irlf = @(x) 1; % impede root life: scales root age regarding root life time

%-----------------------------------------
% Laterals 
%-----------------------------------------

% Parameters editable by the GUI [mean, sd]
p{2}.r = [0.42, 0.14]; % Initial elongation rate (cm/day)
p{2}.a = [0.023, 0]; % Root radius (cm)  
p{2}.theta = [1.48353, 0]; % Insertion angle (rad)
p{2}.lb = [1.04, 1.24]; % Length of basal zone (cm)        
p{2}.la = [1.63, 1.689]; % Length of apical zone (cm)                    
p{2}.ln = [0.82, 1.53]; % Length between laterals (cm)
p{2}.nob = [3, 0]; % Maximal number of laterals (1)

% Additional parameters (predefined values)
p{2}.name = 'Lateral'; % Name of the root type
p{2}.color = [0, 1, 0]; % Color of the root (rgb)
type = 1; % Type of tropism (1: 2:)
N = 1; % Strength of tropism
sigma = 0.3; % Expected change of root tip heading (rad/cm)
p{2}.tropism = [type, N, sigma]; % Root tropism
p{2}.dx = 0.25; % Spatial resolution along root axis (cm)
p{2}.rlt = [Inf, 0]; % Maximal root life time [mean, std] (days)
p{2}.gf = 1; % Type of growth function (1: negative exponential, 2: linear)

% Preset by GUI 
p{2}.successor = [3, 1]; % Laterals [type,probability;type,probability;...]
p{2}.ief = @(x) 1; % impede elongation function: scales root elongation
p{2}.ibf = @(x) 1; % impede branching function: scales branching probability 
p{2}.irlf = @(x) 1; % impede root life: scales root age regarding root life time

%-----------------------------------------
% Second order laterals
%-----------------------------------------

% Parameters editable by the GUI
p{3}.r = [0.89, 0]; % Initial elongation rate (cm/day)
p{3}.a = [0.015, 0]; % Root radius (cm)  
p{3}.theta = [1.48353, 0]; % Insertion angle (rad)
p{3}.la = [0.59, 0.78]; % Length of root (cm)                    

% Additional parameters (predefined values)
p{3}.lb = [0, 0]; % Length of basal zone (cm)        
p{3}.ln = [0, 0]; % Length between laterals (cm)
p{3}.nob = [0, 0]; % Maximal number of laterals (1)
p{3}.name = 'Second order lateral'; % Name of the root type
p{3}.color = [0.5, 0.5, 0]; % Color of the root (rgb)
type = 1; % Type of tropism (1: 2:)
N = 0; % Strength of tropism
sigma = 0.4; % Expected change of root tip heading (rad/cm)
p{3}.tropism = [type, N, sigma]; % Root tropism
p{3}.dx = 0.25; % Spatial resolution along root axis (cm)
p{3}.rlt = [Inf, 0]; % Maximal root life time [mean, std] (days)
p{3}.gf = 1; % Type of growth function (1: negative exponential, 2: linear)

% Preset by GUI 
p{3}.successor = [3, 1]; % Laterals [type,probability;type,probability;...]
p{3}.ief = @(x) 1; % impede elongation function: scales root elongation
p{3}.ibf = @(x) 1; % impede branching function: scales branching probability 
p{3}.irlf = @(x) 1; % impede root life: scales root age regarding root life time

%-----------------------------------------
% Plant data (editable by the GUI)
%-----------------------------------------

plantingdepth = 3; % (cm)
basal_first = [Inf, 0]; % First occurence [mean, std] (days)
basal_delay = [7, 0]; % Interim time [mean, std] (days)

%-----------------------------------------
% Simulation
%-----------------------------------------

% Parameters (editable by the GUI)
simtime = 48;  % simulation time (days)
dt = 48; % temporal resolution, simtime/(intermediate+1) (days) 

% Initialize
p = completeParameters(p); % it is possible to add a container geometry, see completeParameters  
set(0,'RecursionLimit',5000); % sometimes needed
str = createDicotRS(plantingdepth,basal_first,basal_delay,basal_max);% create initial string
N = simtime/dt; % number of iterations

% Run simulation
for i = 1 : N

    str = applyRules(str,dt); % l-system string representing the root system

    %------------------------------------------------------------
    % execute soil model 
    % dependent on the root system (str) at simulation time i*dt
    % see also: getDensity, getSegments, getTotal
    %------------------------------------------------------------
               
    %
    % plant soil interaction takes place using global variables
    %
    % 1. Root tropism (global variables X,Y,Z,C)
    % 2. Impede elongation (function handle ief)
    % 3. Impede branching (function handle ibf)
    % 4. Impede root life time (function handle irlf)
    %
    
    res{i} = str; % save intermediate results

end

%-----------------------------------------
% Visualisation
%-----------------------------------------

figure;
plotTubes(res{end});

% %-----------------------------------------
% % Example evaluation (uncomment and run)
% %-----------------------------------------
%
% v = zeros();
% for i = 1 : N
%     v(i) = getTotal(res{i},'l'); % or 's' for surface, see getTotal
% end
% figure;
% plot((1:N).*dt,v);
% xlabel('Time (days)');
% ylabel('Root system length (cm)'); 


