%========================================================================
% Automatically generated
% Modify this file to describe root-soil interactions
%========================================================================
clear all

rng(1);   %help fate

p = cell(4,1);

%-----------------------------------------
% Tap root
%-----------------------------------------

% Parameters editable by the GUI [mean, sd]
p{1}.r = [3, 0]; % Initial elongation rate (cm/day)
p{1}.a = [0.2, 0]; % Root radius (cm)  
p{1}.lb = [2, 0]; % Length of basal zone (cm)        
p{1}.la = [15, 0]; % Length of apical zone (cm)                    
p{1}.ln = [1, 0]; % Length between laterals (cm)
p{1}.nob = [60, 0]; % Maximal number of laterals (1)

% Additional parameters (predefined values, not altered by GUI)
p{1}.name = 'Tap root'; % Name of the root type
p{1}.color = [0.5, 0, 0]; % Color of the root (rgb)
type = 2; % Type of tropism (0 plagio-, 1 gravi-, 2 exo-, 3 chemo-/hydrotropism)
N = 1; % Strength of tropism
sigma = 0.9; % Expected change of root tip heading (rad/cm)
p{1}.tropism = [type, N, sigma]; % Root tropism
p{1}.dx = 0.25/10; %0.25; % Spatial resolution along root axis (cm)
p{1}.rlt = [Inf, 0]; % Maximal root life time [mean, std] (days)
p{1}.gf = 1; % Type of growth function (1: negative exponential, 2: linear)

% Preset by GUI 
p{1}.theta = [0, 0]; % Insertion angle(rad)
p{1}.successor = []; % Laterals [type,probability;type,probability;...]
p{1}.sef = @(x) 1; % Scale root elongation funcntion
p{1}.sbpf = @(x) 1; % Scale lateral branching probability function
p{1}.saf = @(x) 1; % Scale lateral branching angle function

%-----------------------------------------
% Dicot plant data (editable by the GUI)
%-----------------------------------------

plantingdepth = 3; % (cm)
basal_first = [Inf, 0]; % First occurence [mean, std] (days)
basal_delay = [7, 0]; % Interim time [mean, std] (days)
basal_max = 100; % Maximal number of basal roots (1)

%-----------------------------------------
% Simulation
%-----------------------------------------

% Parameters (editable by the GUI)
simtime = 100;  % simulation time (days)
dt = 100; % temporal resolution, simtime/(intermediate+1) (days) 

% Initialize
p = completeParameters(p); % it is possible to add a container geometry, see completeParameters  
set(0,'RecursionLimit',5000); % sometimes needed
str = createDicotRS(plantingdepth,basal_first,basal_delay,basal_max); % create initial string
N = round(simtime/dt); % number of iterations

% Run simulation
for i = 1 : N

    str = applyRules(str,dt); % l-system string representing the root system

    %------------------------------------------------------------
    % execute soil model 
    % dependent on the root system (str) at simulation time i*dt
    % see also: getDensity, getSegments, getTotal
    %------------------------------------------------------------
               
    %
    % plant soil interaction takes place using global variables
    %
    % 1. Root tropism (global variables X,Y,Z,C)
    % 2. Scale root elongation (function handle sef)
    % 3. Scale root branching probability (function handle sbpf)
    % 4. Scale insertion angle (function handle saf)
    %
    
    res{i} = str; % save intermediate results

end

%-----------------------------------------
% Visualisation
%-----------------------------------------
figure
plotTubes(res{end});
axis equal

% %-----------------------------------------
% % Example evaluation (uncomment and run)
% %-----------------------------------------
%
% v = zeros();
% for i = 1 : N
%     v(i) = getTotal(res{i},'l'); % or 's' for surface, see getTotal
% end
% figure;
% plot((1:N).*dt,v);
% xlabel('Time (days)');
% ylabel('Root system length (cm)'); 


