function objfun = tropismObjective(type, ap)
% getTropismObjective: returns objective function for common tropisms
%           
% Chemotropism use the global variables 'concentration' to look up the
% concentration, with global spatial resolution X,Y,Z.
%
% type      0 plagio-, 1 gravi-, 2 exo-, 3 chemo-/hydrotropism
% (ap)      initial direction (for exotropism), axial resolution (for
%           chemotropism) 
%
% objfun    :objective function describing root tropism
%
% See also: tropism
%
% Copyright 2012-2013 Daniel Leitner. See license.txt for details.
%

switch type  % 0 plagio, 1 gravi, 2 exo, 3 chemo/hydro/...
    case 0
        objfun = @(beta, alpha, y) testH(beta, alpha, y);                
    case 1
        objfun = @(beta, alpha, y) testZ(beta, alpha, y);
    case 2
        objfun = @(beta, alpha, y) testExo(beta, alpha, y, ap);
    case 3        
        objfun = @(beta, alpha, y) testChemo(beta, alpha, y, ap);
end

% for plagiotropism
function z=testH(r,t,y) 
R = y.R *  [ 1 0 0; 0 cos(r) -sin(r); 0 sin(r) cos(r) ]; % roll
R = R *    [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1]; % turn
z = abs(R(3,1)); % minimize abs(z)

% for gravitropism
function z=testZ(r,t,y)
R = y.R * [ 1 0 0; 0 cos(r) -sin(r); 0 sin(r)  cos(r) ]; % roll
R = R * [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1]; % turn
z = R(3,1); % minimize z

% for exotropism
function z=testExo(r,t,y,iR) 
R = y.R * [ 1 0 0; 0 cos(r) -sin(r) ;0 sin(r) cos(r) ]; % roll
R = R * [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1]; % turn
s = (R(:,1)'*iR') / norm(R(:,1)) / norm(iR);
z = acos(s);


% for chemotropism
function z=testChemo(r,t,y,dx) 

global C;
global X;
global Y;
global Z;

%roll left
R = y.R * [ 1 0 0; 0 cos(r) -sin(r) ;0 sin(r) cos(r) ]; % roll
R = R * [ cos(t) sin(t) 0; -sin(t) cos(t) 0; 0 0 1]; % turn
x_ = y.x+dx*R(:,1);
z = -interp3(X,Y,Z,C,x_(1),x_(2),x_(3))*1e6 + R(3,1);

